@@ -4,28 +4,25 @@
 #define OPENBLAS_ARCH_ARM64 1
 #define OPENBLAS_C_GCC 1
 #define OPENBLAS___64BIT__ 1
+#define OPENBLAS_HAVE_C11 1
 #define OPENBLAS_PTHREAD_CREATE_FUNC pthread_create
 #define OPENBLAS_BUNDERSCORE _
 #define OPENBLAS_NEEDBUNDERSCORE 1
 #define OPENBLAS_ARMV8 
 #define OPENBLAS_HAVE_NEON 
 #define OPENBLAS_HAVE_VFPV4 
-#define OPENBLAS_CORTEXA57 
-#define OPENBLAS_L1_CODE_SIZE 49152
-#define OPENBLAS_L1_CODE_LINESIZE 64
-#define OPENBLAS_L1_CODE_ASSOCIATIVE 3
+#define OPENBLAS_CORTEXA53 
 #define OPENBLAS_L1_DATA_SIZE 32768
 #define OPENBLAS_L1_DATA_LINESIZE 64
-#define OPENBLAS_L1_DATA_ASSOCIATIVE 2
-#define OPENBLAS_L2_SIZE 524288
+#define OPENBLAS_L2_SIZE 262144
 #define OPENBLAS_L2_LINESIZE 64
-#define OPENBLAS_L2_ASSOCIATIVE 16
 #define OPENBLAS_DTB_DEFAULT_ENTRIES 64
 #define OPENBLAS_DTB_SIZE 4096
-#define OPENBLAS_NUM_CORES 8
-#define OPENBLAS_CHAR_CORENAME "CORTEXA57"
+#define OPENBLAS_L2_ASSOCIATIVE 4
+#define OPENBLAS_NUM_CORES 6
+#define OPENBLAS_CHAR_CORENAME "CORTEXA53"
 #define OPENBLAS_GEMM_MULTITHREAD_THRESHOLD 4
-#define OPENBLAS_VERSION " OpenBLAS 0.3.10 "
+#define OPENBLAS_VERSION " OpenBLAS 0.3.12 "
 /*This is only for "make install" target.*/
 
 #if defined(OPENBLAS_OS_WINNT) || defined(OPENBLAS_OS_CYGWIN_NT) || defined(OPENBLAS_OS_INTERIX)
@@ -62,6 +59,11 @@ typedef long BLASLONG;
 typedef unsigned long BLASULONG;
 #endif
 
+#ifndef BFLOAT16
+#include <stdint.h>
+typedef uint16_t bfloat16;
+#endif
+
 #ifdef OPENBLAS_USE64BITINT
 typedef BLASLONG blasint;
 #else
